# -*- coding: utf-8 -*-
# Copyright 2020 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
import proto  # type: ignore

from google.analytics.data_v1alpha.types import data


__protobuf__ = proto.module(
    package="google.analytics.data.v1alpha",
    manifest={
        "Metadata",
        "RunReportRequest",
        "RunReportResponse",
        "RunPivotReportRequest",
        "RunPivotReportResponse",
        "BatchRunReportsRequest",
        "BatchRunReportsResponse",
        "BatchRunPivotReportsRequest",
        "BatchRunPivotReportsResponse",
        "GetMetadataRequest",
        "RunRealtimeReportRequest",
        "RunRealtimeReportResponse",
    },
)


class Metadata(proto.Message):
    r"""The dimensions and metrics currently accepted in reporting
    methods.

    Attributes:
        name (str):
            Resource name of this metadata.
        dimensions (Sequence[google.analytics.data_v1alpha.types.DimensionMetadata]):
            The dimension descriptions.
        metrics (Sequence[google.analytics.data_v1alpha.types.MetricMetadata]):
            The metric descriptions.
    """

    name = proto.Field(proto.STRING, number=3,)
    dimensions = proto.RepeatedField(
        proto.MESSAGE, number=1, message=data.DimensionMetadata,
    )
    metrics = proto.RepeatedField(proto.MESSAGE, number=2, message=data.MetricMetadata,)


class RunReportRequest(proto.Message):
    r"""The request to generate a report.
    Attributes:
        entity (google.analytics.data_v1alpha.types.Entity):
            A property whose events are tracked. Within a
            batch request, this entity should either be
            unspecified or consistent with the batch-level
            entity.
        dimensions (Sequence[google.analytics.data_v1alpha.types.Dimension]):
            The dimensions requested and displayed.
        metrics (Sequence[google.analytics.data_v1alpha.types.Metric]):
            The metrics requested and displayed.
        date_ranges (Sequence[google.analytics.data_v1alpha.types.DateRange]):
            Date ranges of data to read. If multiple date ranges are
            requested, each response row will contain a zero based date
            range index. If two date ranges overlap, the event data for
            the overlapping days is included in the response rows for
            both date ranges. In a cohort request, this ``dateRanges``
            must be unspecified.
        offset (int):
            The row count of the start row. The first row is counted as
            row 0.

            To learn more about this pagination parameter, see
            `Pagination <https://developers.google.com/analytics/devguides/reporting/data/v1/basics#pagination>`__.
        limit (int):
            The number of rows to return. If unspecified, 10 rows are
            returned. If -1, all rows are returned.

            To learn more about this pagination parameter, see
            `Pagination <https://developers.google.com/analytics/devguides/reporting/data/v1/basics#pagination>`__.
        metric_aggregations (Sequence[google.analytics.data_v1alpha.types.MetricAggregation]):
            Aggregation of metrics. Aggregated metric values will be
            shown in rows where the dimension_values are set to
            "RESERVED_(MetricAggregation)".
        dimension_filter (google.analytics.data_v1alpha.types.FilterExpression):
            The filter clause of dimensions. Dimensions
            must be requested to be used in this filter.
            Metrics cannot be used in this filter.
        metric_filter (google.analytics.data_v1alpha.types.FilterExpression):
            The filter clause of metrics. Applied at post
            aggregation phase, similar to SQL having-clause.
            Metrics must be requested to be used in this
            filter. Dimensions cannot be used in this
            filter.
        order_bys (Sequence[google.analytics.data_v1alpha.types.OrderBy]):
            Specifies how rows are ordered in the
            response.
        currency_code (str):
            A currency code in ISO4217 format, such as
            "AED", "USD", "JPY". If the field is empty, the
            report uses the entity's default currency.
        cohort_spec (google.analytics.data_v1alpha.types.CohortSpec):
            Cohort group associated with this request. If
            there is a cohort group in the request the
            'cohort' dimension must be present.
        keep_empty_rows (bool):
            If false or unspecified, each row with all
            metrics equal to 0 will not be returned. If
            true, these rows will be returned if they are
            not separately removed by a filter.
        return_property_quota (bool):
            Toggles whether to return the current state of this
            Analytics Property's quota. Quota is returned in
            `PropertyQuota <#PropertyQuota>`__.
    """

    entity = proto.Field(proto.MESSAGE, number=1, message=data.Entity,)
    dimensions = proto.RepeatedField(proto.MESSAGE, number=2, message=data.Dimension,)
    metrics = proto.RepeatedField(proto.MESSAGE, number=3, message=data.Metric,)
    date_ranges = proto.RepeatedField(proto.MESSAGE, number=4, message=data.DateRange,)
    offset = proto.Field(proto.INT64, number=5,)
    limit = proto.Field(proto.INT64, number=6,)
    metric_aggregations = proto.RepeatedField(
        proto.ENUM, number=7, enum=data.MetricAggregation,
    )
    dimension_filter = proto.Field(
        proto.MESSAGE, number=8, message=data.FilterExpression,
    )
    metric_filter = proto.Field(proto.MESSAGE, number=9, message=data.FilterExpression,)
    order_bys = proto.RepeatedField(proto.MESSAGE, number=10, message=data.OrderBy,)
    currency_code = proto.Field(proto.STRING, number=11,)
    cohort_spec = proto.Field(proto.MESSAGE, number=12, message=data.CohortSpec,)
    keep_empty_rows = proto.Field(proto.BOOL, number=13,)
    return_property_quota = proto.Field(proto.BOOL, number=14,)


class RunReportResponse(proto.Message):
    r"""The response report table corresponding to a request.
    Attributes:
        dimension_headers (Sequence[google.analytics.data_v1alpha.types.DimensionHeader]):
            Describes dimension columns. The number of
            DimensionHeaders and ordering of
            DimensionHeaders matches the dimensions present
            in rows.
        metric_headers (Sequence[google.analytics.data_v1alpha.types.MetricHeader]):
            Describes metric columns. The number of
            MetricHeaders and ordering of MetricHeaders
            matches the metrics present in rows.
        rows (Sequence[google.analytics.data_v1alpha.types.Row]):
            Rows of dimension value combinations and
            metric values in the report.
        totals (Sequence[google.analytics.data_v1alpha.types.Row]):
            If requested, the totaled values of metrics.
        maximums (Sequence[google.analytics.data_v1alpha.types.Row]):
            If requested, the maximum values of metrics.
        minimums (Sequence[google.analytics.data_v1alpha.types.Row]):
            If requested, the minimum values of metrics.
        row_count (int):
            The total number of rows in the query result, regardless of
            the number of rows returned in the response. For example if
            a query returns 175 rows and includes limit = 50 in the API
            request, the response will contain row_count = 175 but only
            50 rows.

            To learn more about this pagination parameter, see
            `Pagination <https://developers.google.com/analytics/devguides/reporting/data/v1/basics#pagination>`__.
        metadata (google.analytics.data_v1alpha.types.ResponseMetaData):
            Metadata for the report.
        property_quota (google.analytics.data_v1alpha.types.PropertyQuota):
            This Analytics Property's quota state
            including this request.
    """

    dimension_headers = proto.RepeatedField(
        proto.MESSAGE, number=11, message=data.DimensionHeader,
    )
    metric_headers = proto.RepeatedField(
        proto.MESSAGE, number=1, message=data.MetricHeader,
    )
    rows = proto.RepeatedField(proto.MESSAGE, number=2, message=data.Row,)
    totals = proto.RepeatedField(proto.MESSAGE, number=8, message=data.Row,)
    maximums = proto.RepeatedField(proto.MESSAGE, number=9, message=data.Row,)
    minimums = proto.RepeatedField(proto.MESSAGE, number=10, message=data.Row,)
    row_count = proto.Field(proto.INT32, number=12,)
    metadata = proto.Field(proto.MESSAGE, number=6, message=data.ResponseMetaData,)
    property_quota = proto.Field(proto.MESSAGE, number=7, message=data.PropertyQuota,)


class RunPivotReportRequest(proto.Message):
    r"""The request to generate a pivot report.
    Attributes:
        entity (google.analytics.data_v1alpha.types.Entity):
            A property whose events are tracked. Within a
            batch request, this entity should either be
            unspecified or consistent with the batch-level
            entity.
        dimensions (Sequence[google.analytics.data_v1alpha.types.Dimension]):
            The dimensions requested. All defined dimensions must be
            used by one of the following: dimension_expression,
            dimension_filter, pivots, order_bys.
        metrics (Sequence[google.analytics.data_v1alpha.types.Metric]):
            The metrics requested, at least one metric needs to be
            specified. All defined metrics must be used by one of the
            following: metric_expression, metric_filter, order_bys.
        dimension_filter (google.analytics.data_v1alpha.types.FilterExpression):
            The filter clause of dimensions. Dimensions
            must be requested to be used in this filter.
            Metrics cannot be used in this filter.
        metric_filter (google.analytics.data_v1alpha.types.FilterExpression):
            The filter clause of metrics. Applied at post
            aggregation phase, similar to SQL having-clause.
            Metrics must be requested to be used in this
            filter. Dimensions cannot be used in this
            filter.
        pivots (Sequence[google.analytics.data_v1alpha.types.Pivot]):
            Describes the visual format of the report's
            dimensions in columns or rows. The union of the
            fieldNames (dimension names) in all pivots must
            be a subset of dimension names defined in
            Dimensions. No two pivots can share a dimension.
            A dimension is only visible if it appears in a
            pivot.
        date_ranges (Sequence[google.analytics.data_v1alpha.types.DateRange]):
            The date range to retrieve event data for the report. If
            multiple date ranges are specified, event data from each
            date range is used in the report. A special dimension with
            field name "dateRange" can be included in a Pivot's field
            names; if included, the report compares between date ranges.
            In a cohort request, this ``dateRanges`` must be
            unspecified.
        currency_code (str):
            A currency code in ISO4217 format, such as
            "AED", "USD", "JPY". If the field is empty, the
            report uses the entity's default currency.
        cohort_spec (google.analytics.data_v1alpha.types.CohortSpec):
            Cohort group associated with this request. If
            there is a cohort group in the request the
            'cohort' dimension must be present.
        keep_empty_rows (bool):
            If false or unspecified, each row with all
            metrics equal to 0 will not be returned. If
            true, these rows will be returned if they are
            not separately removed by a filter.
        return_property_quota (bool):
            Toggles whether to return the current state of this
            Analytics Property's quota. Quota is returned in
            `PropertyQuota <#PropertyQuota>`__.
    """

    entity = proto.Field(proto.MESSAGE, number=1, message=data.Entity,)
    dimensions = proto.RepeatedField(proto.MESSAGE, number=2, message=data.Dimension,)
    metrics = proto.RepeatedField(proto.MESSAGE, number=3, message=data.Metric,)
    dimension_filter = proto.Field(
        proto.MESSAGE, number=4, message=data.FilterExpression,
    )
    metric_filter = proto.Field(proto.MESSAGE, number=5, message=data.FilterExpression,)
    pivots = proto.RepeatedField(proto.MESSAGE, number=6, message=data.Pivot,)
    date_ranges = proto.RepeatedField(proto.MESSAGE, number=7, message=data.DateRange,)
    currency_code = proto.Field(proto.STRING, number=8,)
    cohort_spec = proto.Field(proto.MESSAGE, number=9, message=data.CohortSpec,)
    keep_empty_rows = proto.Field(proto.BOOL, number=10,)
    return_property_quota = proto.Field(proto.BOOL, number=11,)


class RunPivotReportResponse(proto.Message):
    r"""The response pivot report table corresponding to a pivot
    request.

    Attributes:
        pivot_headers (Sequence[google.analytics.data_v1alpha.types.PivotHeader]):
            Summarizes the columns and rows created by a pivot. Each
            pivot in the request produces one header in the response. If
            we have a request like this:

            ::

                "pivots": [{
                  "fieldNames": ["country",
                    "city"]
                },
                {
                  "fieldNames": "eventName"
                }]

            We will have the following ``pivotHeaders`` in the response:

            ::

                "pivotHeaders" : [{
                  "dimensionHeaders": [{
                    "dimensionValues": [
                       { "value": "United Kingdom" },
                       { "value": "London" }
                     ]
                  },
                  {
                    "dimensionValues": [
                    { "value": "Japan" },
                    { "value": "Osaka" }
                    ]
                  }]
                },
                {
                  "dimensionHeaders": [{
                    "dimensionValues": [{ "value": "session_start" }]
                  },
                  {
                    "dimensionValues": [{ "value": "scroll" }]
                  }]
                }]
        dimension_headers (Sequence[google.analytics.data_v1alpha.types.DimensionHeader]):
            Describes dimension columns. The number of
            DimensionHeaders and ordering of
            DimensionHeaders matches the dimensions present
            in rows.
        metric_headers (Sequence[google.analytics.data_v1alpha.types.MetricHeader]):
            Describes metric columns. The number of
            MetricHeaders and ordering of MetricHeaders
            matches the metrics present in rows.
        rows (Sequence[google.analytics.data_v1alpha.types.Row]):
            Rows of dimension value combinations and
            metric values in the report.
        aggregates (Sequence[google.analytics.data_v1alpha.types.Row]):
            Aggregation of metric values. Can be totals, minimums, or
            maximums. The returned aggregations are controlled by the
            metric_aggregations in the pivot. The type of aggregation
            returned in each row is shown by the dimension_values which
            are set to "RESERVED\_".
        metadata (google.analytics.data_v1alpha.types.ResponseMetaData):
            Metadata for the report.
        property_quota (google.analytics.data_v1alpha.types.PropertyQuota):
            This Analytics Property's quota state
            including this request.
    """

    pivot_headers = proto.RepeatedField(
        proto.MESSAGE, number=1, message=data.PivotHeader,
    )
    dimension_headers = proto.RepeatedField(
        proto.MESSAGE, number=7, message=data.DimensionHeader,
    )
    metric_headers = proto.RepeatedField(
        proto.MESSAGE, number=2, message=data.MetricHeader,
    )
    rows = proto.RepeatedField(proto.MESSAGE, number=3, message=data.Row,)
    aggregates = proto.RepeatedField(proto.MESSAGE, number=4, message=data.Row,)
    metadata = proto.Field(proto.MESSAGE, number=5, message=data.ResponseMetaData,)
    property_quota = proto.Field(proto.MESSAGE, number=6, message=data.PropertyQuota,)


class BatchRunReportsRequest(proto.Message):
    r"""The batch request containing multiple report requests.
    Attributes:
        entity (google.analytics.data_v1alpha.types.Entity):
            A property whose events are tracked. This
            entity must be specified for the batch. The
            entity within RunReportRequest may either be
            unspecified or consistent with this entity.
        requests (Sequence[google.analytics.data_v1alpha.types.RunReportRequest]):
            Individual requests. Each request has a
            separate report response. Each batch request is
            allowed up to 5 requests.
    """

    entity = proto.Field(proto.MESSAGE, number=1, message=data.Entity,)
    requests = proto.RepeatedField(proto.MESSAGE, number=2, message="RunReportRequest",)


class BatchRunReportsResponse(proto.Message):
    r"""The batch response containing multiple reports.
    Attributes:
        reports (Sequence[google.analytics.data_v1alpha.types.RunReportResponse]):
            Individual responses. Each response has a
            separate report request.
    """

    reports = proto.RepeatedField(proto.MESSAGE, number=1, message="RunReportResponse",)


class BatchRunPivotReportsRequest(proto.Message):
    r"""The batch request containing multiple pivot report requests.
    Attributes:
        entity (google.analytics.data_v1alpha.types.Entity):
            A property whose events are tracked. This
            entity must be specified for the batch. The
            entity within RunPivotReportRequest may either
            be unspecified or consistent with this entity.
        requests (Sequence[google.analytics.data_v1alpha.types.RunPivotReportRequest]):
            Individual requests. Each request has a
            separate pivot report response. Each batch
            request is allowed up to 5 requests.
    """

    entity = proto.Field(proto.MESSAGE, number=1, message=data.Entity,)
    requests = proto.RepeatedField(
        proto.MESSAGE, number=2, message="RunPivotReportRequest",
    )


class BatchRunPivotReportsResponse(proto.Message):
    r"""The batch response containing multiple pivot reports.
    Attributes:
        pivot_reports (Sequence[google.analytics.data_v1alpha.types.RunPivotReportResponse]):
            Individual responses. Each response has a
            separate pivot report request.
    """

    pivot_reports = proto.RepeatedField(
        proto.MESSAGE, number=1, message="RunPivotReportResponse",
    )


class GetMetadataRequest(proto.Message):
    r"""Request for a property's dimension and metric metadata.
    Attributes:
        name (str):
            Required. The resource name of the metadata to retrieve.
            This name field is specified in the URL path and not URL
            parameters. Property is a numeric Google Analytics GA4
            Property identifier. To learn more, see `where to find your
            Property
            ID <https://developers.google.com/analytics/devguides/reporting/data/v1/property-id>`__.

            Example: properties/1234/metadata

            Set the Property ID to 0 for dimensions and metrics common
            to all properties. In this special mode, this method will
            not return custom dimensions and metrics.
    """

    name = proto.Field(proto.STRING, number=1,)


class RunRealtimeReportRequest(proto.Message):
    r"""The request to generate a realtime report.
    Attributes:
        property (str):
            A Google Analytics GA4 property identifier whose events are
            tracked. Specified in the URL path and not the body. To
            learn more, see `where to find your Property
            ID <https://developers.google.com/analytics/devguides/reporting/data/v1/property-id>`__.

            Example: properties/1234
        dimensions (Sequence[google.analytics.data_v1alpha.types.Dimension]):
            The dimensions requested and displayed.
        metrics (Sequence[google.analytics.data_v1alpha.types.Metric]):
            The metrics requested and displayed.
        limit (int):
            The number of rows to return. If unspecified,
            10 rows are returned. If -1, all rows are
            returned.
        dimension_filter (google.analytics.data_v1alpha.types.FilterExpression):
            The filter clause of dimensions. Dimensions
            must be requested to be used in this filter.
            Metrics cannot be used in this filter.
        metric_filter (google.analytics.data_v1alpha.types.FilterExpression):
            The filter clause of metrics. Applied at post
            aggregation phase, similar to SQL having-clause.
            Metrics must be requested to be used in this
            filter. Dimensions cannot be used in this
            filter.
        metric_aggregations (Sequence[google.analytics.data_v1alpha.types.MetricAggregation]):
            Aggregation of metrics. Aggregated metric values will be
            shown in rows where the dimension_values are set to
            "RESERVED_(MetricAggregation)".
        order_bys (Sequence[google.analytics.data_v1alpha.types.OrderBy]):
            Specifies how rows are ordered in the
            response.
        return_property_quota (bool):
            Toggles whether to return the current state of this
            Analytics Property's Realtime quota. Quota is returned in
            `PropertyQuota <#PropertyQuota>`__.
    """

    property = proto.Field(proto.STRING, number=1,)
    dimensions = proto.RepeatedField(proto.MESSAGE, number=2, message=data.Dimension,)
    metrics = proto.RepeatedField(proto.MESSAGE, number=3, message=data.Metric,)
    limit = proto.Field(proto.INT64, number=4,)
    dimension_filter = proto.Field(
        proto.MESSAGE, number=5, message=data.FilterExpression,
    )
    metric_filter = proto.Field(proto.MESSAGE, number=6, message=data.FilterExpression,)
    metric_aggregations = proto.RepeatedField(
        proto.ENUM, number=7, enum=data.MetricAggregation,
    )
    order_bys = proto.RepeatedField(proto.MESSAGE, number=8, message=data.OrderBy,)
    return_property_quota = proto.Field(proto.BOOL, number=9,)


class RunRealtimeReportResponse(proto.Message):
    r"""The response realtime report table corresponding to a
    request.

    Attributes:
        dimension_headers (Sequence[google.analytics.data_v1alpha.types.DimensionHeader]):
            Describes dimension columns. The number of
            DimensionHeaders and ordering of
            DimensionHeaders matches the dimensions present
            in rows.
        metric_headers (Sequence[google.analytics.data_v1alpha.types.MetricHeader]):
            Describes metric columns. The number of
            MetricHeaders and ordering of MetricHeaders
            matches the metrics present in rows.
        rows (Sequence[google.analytics.data_v1alpha.types.Row]):
            Rows of dimension value combinations and
            metric values in the report.
        totals (Sequence[google.analytics.data_v1alpha.types.Row]):
            If requested, the totaled values of metrics.
        maximums (Sequence[google.analytics.data_v1alpha.types.Row]):
            If requested, the maximum values of metrics.
        minimums (Sequence[google.analytics.data_v1alpha.types.Row]):
            If requested, the minimum values of metrics.
        row_count (int):
            The total number of rows in the query result, regardless of
            the number of rows returned in the response. For example if
            a query returns 175 rows and includes limit = 50 in the API
            request, the response will contain row_count = 175 but only
            50 rows.
        property_quota (google.analytics.data_v1alpha.types.PropertyQuota):
            This Analytics Property's Realtime quota
            state including this request.
    """

    dimension_headers = proto.RepeatedField(
        proto.MESSAGE, number=1, message=data.DimensionHeader,
    )
    metric_headers = proto.RepeatedField(
        proto.MESSAGE, number=2, message=data.MetricHeader,
    )
    rows = proto.RepeatedField(proto.MESSAGE, number=3, message=data.Row,)
    totals = proto.RepeatedField(proto.MESSAGE, number=4, message=data.Row,)
    maximums = proto.RepeatedField(proto.MESSAGE, number=5, message=data.Row,)
    minimums = proto.RepeatedField(proto.MESSAGE, number=6, message=data.Row,)
    row_count = proto.Field(proto.INT32, number=7,)
    property_quota = proto.Field(proto.MESSAGE, number=8, message=data.PropertyQuota,)


__all__ = tuple(sorted(__protobuf__.manifest))



# -*- coding: utf-8 -*-
# Copyright 2020 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
from .analytics_data_api import (
    BatchRunPivotReportsRequest,
    BatchRunPivotReportsResponse,
    BatchRunReportsRequest,
    BatchRunReportsResponse,
    GetMetadataRequest,
    Metadata,
    RunPivotReportRequest,
    RunPivotReportResponse,
    RunRealtimeReportRequest,
    RunRealtimeReportResponse,
    RunReportRequest,
    RunReportResponse,
)
from .data import (
    Cohort,
    CohortReportSettings,
    CohortSpec,
    CohortsRange,
    DateRange,
    Dimension,
    DimensionExpression,
    DimensionHeader,
    DimensionMetadata,
    DimensionValue,
    Filter,
    FilterExpression,
    FilterExpressionList,
    Metric,
    MetricHeader,
    MetricMetadata,
    MetricValue,
    MinuteRange,
    NumericValue,
    OrderBy,
    Pivot,
    PivotDimensionHeader,
    PivotHeader,
    PropertyQuota,
    QuotaStatus,
    ResponseMetaData,
    Row,
    MetricAggregation,
    MetricType,
)

__all__ = (
    "BatchRunPivotReportsRequest",
    "BatchRunPivotReportsResponse",
    "BatchRunReportsRequest",
    "BatchRunReportsResponse",
    "GetMetadataRequest",
    "Metadata",
    "RunPivotReportRequest",
    "RunPivotReportResponse",
    "RunRealtimeReportRequest",
    "RunRealtimeReportResponse",
    "RunReportRequest",
    "RunReportResponse",
    "Cohort",
    "CohortReportSettings",
    "CohortSpec",
    "CohortsRange",
    "DateRange",
    "Dimension",
    "DimensionExpression",
    "DimensionHeader",
    "DimensionMetadata",
    "DimensionValue",
    "Filter",
    "FilterExpression",
    "FilterExpressionList",
    "Metric",
    "MetricHeader",
    "MetricMetadata",
    "MetricValue",
    "MinuteRange",
    "NumericValue",
    "OrderBy",
    "Pivot",
    "PivotDimensionHeader",
    "PivotHeader",
    "PropertyQuota",
    "QuotaStatus",
    "ResponseMetaData",
    "Row",
    "MetricAggregation",
    "MetricType",
)



# -*- coding: utf-8 -*-
# Copyright 2020 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
import proto  # type: ignore

from google.analytics.data_v1beta.types import data


__protobuf__ = proto.module(
    package="google.analytics.data.v1beta",
    manifest={
        "Metadata",
        "RunReportRequest",
        "RunReportResponse",
        "RunPivotReportRequest",
        "RunPivotReportResponse",
        "BatchRunReportsRequest",
        "BatchRunReportsResponse",
        "BatchRunPivotReportsRequest",
        "BatchRunPivotReportsResponse",
        "GetMetadataRequest",
        "RunRealtimeReportRequest",
        "RunRealtimeReportResponse",
    },
)


class Metadata(proto.Message):
    r"""The dimensions and metrics currently accepted in reporting
    methods.

    Attributes:
        name (str):
            Resource name of this metadata.
        dimensions (Sequence[google.analytics.data_v1beta.types.DimensionMetadata]):
            The dimension descriptions.
        metrics (Sequence[google.analytics.data_v1beta.types.MetricMetadata]):
            The metric descriptions.
    """

    name = proto.Field(proto.STRING, number=3,)
    dimensions = proto.RepeatedField(
        proto.MESSAGE, number=1, message=data.DimensionMetadata,
    )
    metrics = proto.RepeatedField(proto.MESSAGE, number=2, message=data.MetricMetadata,)


class RunReportRequest(proto.Message):
    r"""The request to generate a report.
    Attributes:
        property (str):
            A Google Analytics GA4 property identifier whose events are
            tracked. Specified in the URL path and not the body. To
            learn more, see `where to find your Property
            ID <https://developers.google.com/analytics/devguides/reporting/data/v1/property-id>`__.
            Within a batch request, this property should either be
            unspecified or consistent with the batch-level property.

            Example: properties/1234
        dimensions (Sequence[google.analytics.data_v1beta.types.Dimension]):
            The dimensions requested and displayed.
        metrics (Sequence[google.analytics.data_v1beta.types.Metric]):
            The metrics requested and displayed.
        date_ranges (Sequence[google.analytics.data_v1beta.types.DateRange]):
            Date ranges of data to read. If multiple date ranges are
            requested, each response row will contain a zero based date
            range index. If two date ranges overlap, the event data for
            the overlapping days is included in the response rows for
            both date ranges. In a cohort request, this ``dateRanges``
            must be unspecified.
        dimension_filter (google.analytics.data_v1beta.types.FilterExpression):
            The filter clause of dimensions. Dimensions
            must be requested to be used in this filter.
            Metrics cannot be used in this filter.
        metric_filter (google.analytics.data_v1beta.types.FilterExpression):
            The filter clause of metrics. Applied at post
            aggregation phase, similar to SQL having-clause.
            Metrics must be requested to be used in this
            filter. Dimensions cannot be used in this
            filter.
        offset (int):
            The row count of the start row. The first row is counted as
            row 0.

            When paging, the first request does not specify offset; or
            equivalently, sets offset to 0; the first request returns
            the first ``limit`` of rows. The second request sets offset
            to the ``limit`` of the first request; the second request
            returns the second ``limit`` of rows.

            To learn more about this pagination parameter, see
            `Pagination <https://developers.google.com/analytics/devguides/reporting/data/v1/basics#pagination>`__.
        limit (int):
            The number of rows to return. If unspecified, 10,000 rows
            are returned. The API returns a maximum of 100,000 rows per
            request, no matter how many you ask for. ``limit`` must be
            positive.

            The API can also return fewer rows than the requested
            ``limit``, if there aren't as many dimension values as the
            ``limit``. For instance, there are fewer than 300 possible
            values for the dimension ``country``, so when reporting on
            only ``country``, you can't get more than 300 rows, even if
            you set ``limit`` to a higher value.

            To learn more about this pagination parameter, see
            `Pagination <https://developers.google.com/analytics/devguides/reporting/data/v1/basics#pagination>`__.
        metric_aggregations (Sequence[google.analytics.data_v1beta.types.MetricAggregation]):
            Aggregation of metrics. Aggregated metric values will be
            shown in rows where the dimension_values are set to
            "RESERVED_(MetricAggregation)".
        order_bys (Sequence[google.analytics.data_v1beta.types.OrderBy]):
            Specifies how rows are ordered in the
            response.
        currency_code (str):
            A currency code in ISO4217 format, such as
            "AED", "USD", "JPY". If the field is empty, the
            report uses the property's default currency.
        cohort_spec (google.analytics.data_v1beta.types.CohortSpec):
            Cohort group associated with this request. If
            there is a cohort group in the request the
            'cohort' dimension must be present.
        keep_empty_rows (bool):
            If false or unspecified, each row with all
            metrics equal to 0 will not be returned. If
            true, these rows will be returned if they are
            not separately removed by a filter.
        return_property_quota (bool):
            Toggles whether to return the current state of this
            Analytics Property's quota. Quota is returned in
            `PropertyQuota <#PropertyQuota>`__.
    """

    property = proto.Field(proto.STRING, number=1,)
    dimensions = proto.RepeatedField(proto.MESSAGE, number=2, message=data.Dimension,)
    metrics = proto.RepeatedField(proto.MESSAGE, number=3, message=data.Metric,)
    date_ranges = proto.RepeatedField(proto.MESSAGE, number=4, message=data.DateRange,)
    dimension_filter = proto.Field(
        proto.MESSAGE, number=5, message=data.FilterExpression,
    )
    metric_filter = proto.Field(proto.MESSAGE, number=6, message=data.FilterExpression,)
    offset = proto.Field(proto.INT64, number=7,)
    limit = proto.Field(proto.INT64, number=8,)
    metric_aggregations = proto.RepeatedField(
        proto.ENUM, number=9, enum=data.MetricAggregation,
    )
    order_bys = proto.RepeatedField(proto.MESSAGE, number=10, message=data.OrderBy,)
    currency_code = proto.Field(proto.STRING, number=11,)
    cohort_spec = proto.Field(proto.MESSAGE, number=12, message=data.CohortSpec,)
    keep_empty_rows = proto.Field(proto.BOOL, number=13,)
    return_property_quota = proto.Field(proto.BOOL, number=14,)


class RunReportResponse(proto.Message):
    r"""The response report table corresponding to a request.
    Attributes:
        dimension_headers (Sequence[google.analytics.data_v1beta.types.DimensionHeader]):
            Describes dimension columns. The number of
            DimensionHeaders and ordering of
            DimensionHeaders matches the dimensions present
            in rows.
        metric_headers (Sequence[google.analytics.data_v1beta.types.MetricHeader]):
            Describes metric columns. The number of
            MetricHeaders and ordering of MetricHeaders
            matches the metrics present in rows.
        rows (Sequence[google.analytics.data_v1beta.types.Row]):
            Rows of dimension value combinations and
            metric values in the report.
        totals (Sequence[google.analytics.data_v1beta.types.Row]):
            If requested, the totaled values of metrics.
        maximums (Sequence[google.analytics.data_v1beta.types.Row]):
            If requested, the maximum values of metrics.
        minimums (Sequence[google.analytics.data_v1beta.types.Row]):
            If requested, the minimum values of metrics.
        row_count (int):
            The total number of rows in the query result. ``rowCount``
            is independent of the number of rows returned in the
            response, the ``limit`` request parameter, and the
            ``offset`` request parameter. For example if a query returns
            175 rows and includes ``limit`` of 50 in the API request,
            the response will contain ``rowCount`` of 175 but only 50
            rows.

            To learn more about this pagination parameter, see
            `Pagination <https://developers.google.com/analytics/devguides/reporting/data/v1/basics#pagination>`__.
        metadata (google.analytics.data_v1beta.types.ResponseMetaData):
            Metadata for the report.
        property_quota (google.analytics.data_v1beta.types.PropertyQuota):
            This Analytics Property's quota state
            including this request.
        kind (str):
            Identifies what kind of resource this message is. This
            ``kind`` is always the fixed string
            "analyticsData#runReport". Useful to distinguish between
            response types in JSON.
    """

    dimension_headers = proto.RepeatedField(
        proto.MESSAGE, number=1, message=data.DimensionHeader,
    )
    metric_headers = proto.RepeatedField(
        proto.MESSAGE, number=2, message=data.MetricHeader,
    )
    rows = proto.RepeatedField(proto.MESSAGE, number=3, message=data.Row,)
    totals = proto.RepeatedField(proto.MESSAGE, number=4, message=data.Row,)
    maximums = proto.RepeatedField(proto.MESSAGE, number=5, message=data.Row,)
    minimums = proto.RepeatedField(proto.MESSAGE, number=6, message=data.Row,)
    row_count = proto.Field(proto.INT32, number=7,)
    metadata = proto.Field(proto.MESSAGE, number=8, message=data.ResponseMetaData,)
    property_quota = proto.Field(proto.MESSAGE, number=9, message=data.PropertyQuota,)
    kind = proto.Field(proto.STRING, number=10,)


class RunPivotReportRequest(proto.Message):
    r"""The request to generate a pivot report.
    Attributes:
        property (str):
            A Google Analytics GA4 property identifier whose events are
            tracked. Specified in the URL path and not the body. To
            learn more, see `where to find your Property
            ID <https://developers.google.com/analytics/devguides/reporting/data/v1/property-id>`__.
            Within a batch request, this property should either be
            unspecified or consistent with the batch-level property.

            Example: properties/1234
        dimensions (Sequence[google.analytics.data_v1beta.types.Dimension]):
            The dimensions requested. All defined dimensions must be
            used by one of the following: dimension_expression,
            dimension_filter, pivots, order_bys.
        metrics (Sequence[google.analytics.data_v1beta.types.Metric]):
            The metrics requested, at least one metric needs to be
            specified. All defined metrics must be used by one of the
            following: metric_expression, metric_filter, order_bys.
        date_ranges (Sequence[google.analytics.data_v1beta.types.DateRange]):
            The date range to retrieve event data for the report. If
            multiple date ranges are specified, event data from each
            date range is used in the report. A special dimension with
            field name "dateRange" can be included in a Pivot's field
            names; if included, the report compares between date ranges.
            In a cohort request, this ``dateRanges`` must be
            unspecified.
        pivots (Sequence[google.analytics.data_v1beta.types.Pivot]):
            Describes the visual format of the report's
            dimensions in columns or rows. The union of the
            fieldNames (dimension names) in all pivots must
            be a subset of dimension names defined in
            Dimensions. No two pivots can share a dimension.
            A dimension is only visible if it appears in a
            pivot.
        dimension_filter (google.analytics.data_v1beta.types.FilterExpression):
            The filter clause of dimensions. Dimensions
            must be requested to be used in this filter.
            Metrics cannot be used in this filter.
        metric_filter (google.analytics.data_v1beta.types.FilterExpression):
            The filter clause of metrics. Applied at post
            aggregation phase, similar to SQL having-clause.
            Metrics must be requested to be used in this
            filter. Dimensions cannot be used in this
            filter.
        currency_code (str):
            A currency code in ISO4217 format, such as
            "AED", "USD", "JPY". If the field is empty, the
            report uses the property's default currency.
        cohort_spec (google.analytics.data_v1beta.types.CohortSpec):
            Cohort group associated with this request. If
            there is a cohort group in the request the
            'cohort' dimension must be present.
        keep_empty_rows (bool):
            If false or unspecified, each row with all
            metrics equal to 0 will not be returned. If
            true, these rows will be returned if they are
            not separately removed by a filter.
        return_property_quota (bool):
            Toggles whether to return the current state of this
            Analytics Property's quota. Quota is returned in
            `PropertyQuota <#PropertyQuota>`__.
    """

    property = proto.Field(proto.STRING, number=1,)
    dimensions = proto.RepeatedField(proto.MESSAGE, number=2, message=data.Dimension,)
    metrics = proto.RepeatedField(proto.MESSAGE, number=3, message=data.Metric,)
    date_ranges = proto.RepeatedField(proto.MESSAGE, number=4, message=data.DateRange,)
    pivots = proto.RepeatedField(proto.MESSAGE, number=5, message=data.Pivot,)
    dimension_filter = proto.Field(
        proto.MESSAGE, number=6, message=data.FilterExpression,
    )
    metric_filter = proto.Field(proto.MESSAGE, number=7, message=data.FilterExpression,)
    currency_code = proto.Field(proto.STRING, number=8,)
    cohort_spec = proto.Field(proto.MESSAGE, number=9, message=data.CohortSpec,)
    keep_empty_rows = proto.Field(proto.BOOL, number=10,)
    return_property_quota = proto.Field(proto.BOOL, number=11,)


class RunPivotReportResponse(proto.Message):
    r"""The response pivot report table corresponding to a pivot
    request.

    Attributes:
        pivot_headers (Sequence[google.analytics.data_v1beta.types.PivotHeader]):
            Summarizes the columns and rows created by a pivot. Each
            pivot in the request produces one header in the response. If
            we have a request like this:

            ::

                "pivots": [{
                  "fieldNames": ["country",
                    "city"]
                },
                {
                  "fieldNames": "eventName"
                }]

            We will have the following ``pivotHeaders`` in the response:

            ::

                "pivotHeaders" : [{
                  "dimensionHeaders": [{
                    "dimensionValues": [
                       { "value": "United Kingdom" },
                       { "value": "London" }
                     ]
                  },
                  {
                    "dimensionValues": [
                    { "value": "Japan" },
                    { "value": "Osaka" }
                    ]
                  }]
                },
                {
                  "dimensionHeaders": [{
                    "dimensionValues": [{ "value": "session_start" }]
                  },
                  {
                    "dimensionValues": [{ "value": "scroll" }]
                  }]
                }]
        dimension_headers (Sequence[google.analytics.data_v1beta.types.DimensionHeader]):
            Describes dimension columns. The number of
            DimensionHeaders and ordering of
            DimensionHeaders matches the dimensions present
            in rows.
        metric_headers (Sequence[google.analytics.data_v1beta.types.MetricHeader]):
            Describes metric columns. The number of
            MetricHeaders and ordering of MetricHeaders
            matches the metrics present in rows.
        rows (Sequence[google.analytics.data_v1beta.types.Row]):
            Rows of dimension value combinations and
            metric values in the report.
        aggregates (Sequence[google.analytics.data_v1beta.types.Row]):
            Aggregation of metric values. Can be totals, minimums, or
            maximums. The returned aggregations are controlled by the
            metric_aggregations in the pivot. The type of aggregation
            returned in each row is shown by the dimension_values which
            are set to "RESERVED\_".
        metadata (google.analytics.data_v1beta.types.ResponseMetaData):
            Metadata for the report.
        property_quota (google.analytics.data_v1beta.types.PropertyQuota):
            This Analytics Property's quota state
            including this request.
        kind (str):
            Identifies what kind of resource this message is. This
            ``kind`` is always the fixed string
            "analyticsData#runPivotReport". Useful to distinguish
            between response types in JSON.
    """

    pivot_headers = proto.RepeatedField(
        proto.MESSAGE, number=1, message=data.PivotHeader,
    )
    dimension_headers = proto.RepeatedField(
        proto.MESSAGE, number=2, message=data.DimensionHeader,
    )
    metric_headers = proto.RepeatedField(
        proto.MESSAGE, number=3, message=data.MetricHeader,
    )
    rows = proto.RepeatedField(proto.MESSAGE, number=4, message=data.Row,)
    aggregates = proto.RepeatedField(proto.MESSAGE, number=5, message=data.Row,)
    metadata = proto.Field(proto.MESSAGE, number=6, message=data.ResponseMetaData,)
    property_quota = proto.Field(proto.MESSAGE, number=7, message=data.PropertyQuota,)
    kind = proto.Field(proto.STRING, number=8,)


class BatchRunReportsRequest(proto.Message):
    r"""The batch request containing multiple report requests.
    Attributes:
        property (str):
            A Google Analytics GA4 property identifier whose events are
            tracked. Specified in the URL path and not the body. To
            learn more, see `where to find your Property
            ID <https://developers.google.com/analytics/devguides/reporting/data/v1/property-id>`__.
            This property must be specified for the batch. The property
            within RunReportRequest may either be unspecified or
            consistent with this property.

            Example: properties/1234
        requests (Sequence[google.analytics.data_v1beta.types.RunReportRequest]):
            Individual requests. Each request has a
            separate report response. Each batch request is
            allowed up to 5 requests.
    """

    property = proto.Field(proto.STRING, number=1,)
    requests = proto.RepeatedField(proto.MESSAGE, number=2, message="RunReportRequest",)


class BatchRunReportsResponse(proto.Message):
    r"""The batch response containing multiple reports.
    Attributes:
        reports (Sequence[google.analytics.data_v1beta.types.RunReportResponse]):
            Individual responses. Each response has a
            separate report request.
        kind (str):
            Identifies what kind of resource this message is. This
            ``kind`` is always the fixed string
            "analyticsData#batchRunReports". Useful to distinguish
            between response types in JSON.
    """

    reports = proto.RepeatedField(proto.MESSAGE, number=1, message="RunReportResponse",)
    kind = proto.Field(proto.STRING, number=2,)


class BatchRunPivotReportsRequest(proto.Message):
    r"""The batch request containing multiple pivot report requests.
    Attributes:
        property (str):
            A Google Analytics GA4 property identifier whose events are
            tracked. Specified in the URL path and not the body. To
            learn more, see `where to find your Property
            ID <https://developers.google.com/analytics/devguides/reporting/data/v1/property-id>`__.
            This property must be specified for the batch. The property
            within RunPivotReportRequest may either be unspecified or
            consistent with this property.

            Example: properties/1234
        requests (Sequence[google.analytics.data_v1beta.types.RunPivotReportRequest]):
            Individual requests. Each request has a
            separate pivot report response. Each batch
            request is allowed up to 5 requests.
    """

    property = proto.Field(proto.STRING, number=1,)
    requests = proto.RepeatedField(
        proto.MESSAGE, number=2, message="RunPivotReportRequest",
    )


class BatchRunPivotReportsResponse(proto.Message):
    r"""The batch response containing multiple pivot reports.
    Attributes:
        pivot_reports (Sequence[google.analytics.data_v1beta.types.RunPivotReportResponse]):
            Individual responses. Each response has a
            separate pivot report request.
        kind (str):
            Identifies what kind of resource this message is. This
            ``kind`` is always the fixed string
            "analyticsData#batchRunPivotReports". Useful to distinguish
            between response types in JSON.
    """

    pivot_reports = proto.RepeatedField(
        proto.MESSAGE, number=1, message="RunPivotReportResponse",
    )
    kind = proto.Field(proto.STRING, number=2,)


class GetMetadataRequest(proto.Message):
    r"""Request for a property's dimension and metric metadata.
    Attributes:
        name (str):
            Required. The resource name of the metadata to retrieve.
            This name field is specified in the URL path and not URL
            parameters. Property is a numeric Google Analytics GA4
            Property identifier. To learn more, see `where to find your
            Property
            ID <https://developers.google.com/analytics/devguides/reporting/data/v1/property-id>`__.

            Example: properties/1234/metadata

            Set the Property ID to 0 for dimensions and metrics common
            to all properties. In this special mode, this method will
            not return custom dimensions and metrics.
    """

    name = proto.Field(proto.STRING, number=1,)


class RunRealtimeReportRequest(proto.Message):
    r"""The request to generate a realtime report.
    Attributes:
        property (str):
            A Google Analytics GA4 property identifier whose events are
            tracked. Specified in the URL path and not the body. To
            learn more, see `where to find your Property
            ID <https://developers.google.com/analytics/devguides/reporting/data/v1/property-id>`__.

            Example: properties/1234
        dimensions (Sequence[google.analytics.data_v1beta.types.Dimension]):
            The dimensions requested and displayed.
        metrics (Sequence[google.analytics.data_v1beta.types.Metric]):
            The metrics requested and displayed.
        dimension_filter (google.analytics.data_v1beta.types.FilterExpression):
            The filter clause of dimensions. Dimensions
            must be requested to be used in this filter.
            Metrics cannot be used in this filter.
        metric_filter (google.analytics.data_v1beta.types.FilterExpression):
            The filter clause of metrics. Applied at post
            aggregation phase, similar to SQL having-clause.
            Metrics must be requested to be used in this
            filter. Dimensions cannot be used in this
            filter.
        limit (int):
            The number of rows to return. If unspecified, 10,000 rows
            are returned. The API returns a maximum of 100,000 rows per
            request, no matter how many you ask for. ``limit`` must be
            positive.

            The API can also return fewer rows than the requested
            ``limit``, if there aren't as many dimension values as the
            ``limit``. For instance, there are fewer than 300 possible
            values for the dimension ``country``, so when reporting on
            only ``country``, you can't get more than 300 rows, even if
            you set ``limit`` to a higher value.
        metric_aggregations (Sequence[google.analytics.data_v1beta.types.MetricAggregation]):
            Aggregation of metrics. Aggregated metric values will be
            shown in rows where the dimension_values are set to
            "RESERVED_(MetricAggregation)".
        order_bys (Sequence[google.analytics.data_v1beta.types.OrderBy]):
            Specifies how rows are ordered in the
            response.
        return_property_quota (bool):
            Toggles whether to return the current state of this
            Analytics Property's Realtime quota. Quota is returned in
            `PropertyQuota <#PropertyQuota>`__.
        minute_ranges (Sequence[google.analytics.data_v1beta.types.MinuteRange]):
            The minute ranges of event data to read. If
            unspecified, one minute range for the last 30
            minutes will be used. If multiple minute ranges
            are requested, each response row will contain a
            zero based minute range index. If two minute
            ranges overlap, the event data for the
            overlapping minutes is included in the response
            rows for both minute ranges.
    """

    property = proto.Field(proto.STRING, number=1,)
    dimensions = proto.RepeatedField(proto.MESSAGE, number=2, message=data.Dimension,)
    metrics = proto.RepeatedField(proto.MESSAGE, number=3, message=data.Metric,)
    dimension_filter = proto.Field(
        proto.MESSAGE, number=4, message=data.FilterExpression,
    )
    metric_filter = proto.Field(proto.MESSAGE, number=5, message=data.FilterExpression,)
    limit = proto.Field(proto.INT64, number=6,)
    metric_aggregations = proto.RepeatedField(
        proto.ENUM, number=7, enum=data.MetricAggregation,
    )
    order_bys = proto.RepeatedField(proto.MESSAGE, number=8, message=data.OrderBy,)
    return_property_quota = proto.Field(proto.BOOL, number=9,)
    minute_ranges = proto.RepeatedField(
        proto.MESSAGE, number=10, message=data.MinuteRange,
    )


class RunRealtimeReportResponse(proto.Message):
    r"""The response realtime report table corresponding to a
    request.

    Attributes:
        dimension_headers (Sequence[google.analytics.data_v1beta.types.DimensionHeader]):
            Describes dimension columns. The number of
            DimensionHeaders and ordering of
            DimensionHeaders matches the dimensions present
            in rows.
        metric_headers (Sequence[google.analytics.data_v1beta.types.MetricHeader]):
            Describes metric columns. The number of
            MetricHeaders and ordering of MetricHeaders
            matches the metrics present in rows.
        rows (Sequence[google.analytics.data_v1beta.types.Row]):
            Rows of dimension value combinations and
            metric values in the report.
        totals (Sequence[google.analytics.data_v1beta.types.Row]):
            If requested, the totaled values of metrics.
        maximums (Sequence[google.analytics.data_v1beta.types.Row]):
            If requested, the maximum values of metrics.
        minimums (Sequence[google.analytics.data_v1beta.types.Row]):
            If requested, the minimum values of metrics.
        row_count (int):
            The total number of rows in the query result. ``rowCount``
            is independent of the number of rows returned in the
            response and the ``limit`` request parameter. For example if
            a query returns 175 rows and includes ``limit`` of 50 in the
            API request, the response will contain ``rowCount`` of 175
            but only 50 rows.
        property_quota (google.analytics.data_v1beta.types.PropertyQuota):
            This Analytics Property's Realtime quota
            state including this request.
        kind (str):
            Identifies what kind of resource this message is. This
            ``kind`` is always the fixed string
            "analyticsData#runRealtimeReport". Useful to distinguish
            between response types in JSON.
    """

    dimension_headers = proto.RepeatedField(
        proto.MESSAGE, number=1, message=data.DimensionHeader,
    )
    metric_headers = proto.RepeatedField(
        proto.MESSAGE, number=2, message=data.MetricHeader,
    )
    rows = proto.RepeatedField(proto.MESSAGE, number=3, message=data.Row,)
    totals = proto.RepeatedField(proto.MESSAGE, number=4, message=data.Row,)
    maximums = proto.RepeatedField(proto.MESSAGE, number=5, message=data.Row,)
    minimums = proto.RepeatedField(proto.MESSAGE, number=6, message=data.Row,)
    row_count = proto.Field(proto.INT32, number=7,)
    property_quota = proto.Field(proto.MESSAGE, number=8, message=data.PropertyQuota,)
    kind = proto.Field(proto.STRING, number=9,)


__all__ = tuple(sorted(__protobuf__.manifest))



# -*- coding: utf-8 -*-
# Copyright 2020 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
import proto  # type: ignore


__protobuf__ = proto.module(
    package="google.analytics.data.v1alpha",
    manifest={
        "MetricAggregation",
        "MetricType",
        "DateRange",
        "Entity",
        "Dimension",
        "DimensionExpression",
        "Metric",
        "FilterExpression",
        "FilterExpressionList",
        "Filter",
        "OrderBy",
        "Pivot",
        "CohortSpec",
        "Cohort",
        "CohortsRange",
        "CohortReportSettings",
        "ResponseMetaData",
        "DimensionHeader",
        "MetricHeader",
        "PivotHeader",
        "PivotDimensionHeader",
        "Row",
        "DimensionValue",
        "MetricValue",
        "NumericValue",
        "PropertyQuota",
        "QuotaStatus",
        "DimensionMetadata",
        "MetricMetadata",
    },
)


class MetricAggregation(proto.Enum):
    r"""Represents aggregation of metrics."""
    METRIC_AGGREGATION_UNSPECIFIED = 0
    TOTAL = 1
    MINIMUM = 5
    MAXIMUM = 6
    COUNT = 4


class MetricType(proto.Enum):
    r"""A metric's value type."""
    METRIC_TYPE_UNSPECIFIED = 0
    TYPE_INTEGER = 1
    TYPE_FLOAT = 2
    TYPE_SECONDS = 4
    TYPE_MILLISECONDS = 5
    TYPE_MINUTES = 6
    TYPE_HOURS = 7
    TYPE_STANDARD = 8
    TYPE_CURRENCY = 9
    TYPE_FEET = 10
    TYPE_MILES = 11
    TYPE_METERS = 12
    TYPE_KILOMETERS = 13


class DateRange(proto.Message):
    r"""A contiguous set of days: startDate, startDate + 1, ...,
    endDate. Requests are allowed up to 4 date ranges.

    Attributes:
        start_date (str):
            The inclusive start date for the query in the format
            ``YYYY-MM-DD``. Cannot be after ``end_date``. The format
            ``NdaysAgo``, ``yesterday``, or ``today`` is also accepted,
            and in that case, the date is inferred based on the
            property's reporting time zone.
        end_date (str):
            The inclusive end date for the query in the format
            ``YYYY-MM-DD``. Cannot be before ``start_date``. The format
            ``NdaysAgo``, ``yesterday``, or ``today`` is also accepted,
            and in that case, the date is inferred based on the
            property's reporting time zone.
        name (str):
            Assigns a name to this date range. The dimension
            ``dateRange`` is valued to this name in a report response.
            If set, cannot begin with ``date_range_`` or ``RESERVED_``.
            If not set, date ranges are named by their zero based index
            in the request: ``date_range_0``, ``date_range_1``, etc.
    """

    start_date = proto.Field(proto.STRING, number=1,)
    end_date = proto.Field(proto.STRING, number=2,)
    name = proto.Field(proto.STRING, number=3,)


class Entity(proto.Message):
    r"""The unique identifier of the property whose events are
    tracked.

    Attributes:
        property_id (str):
            A Google Analytics GA4 property id. To learn more, see
            `where to find your Property
            ID <https://developers.google.com/analytics/devguides/reporting/data/v1/property-id>`__.
    """

    property_id = proto.Field(proto.STRING, number=1,)


class Dimension(proto.Message):
    r"""Dimensions are attributes of your data. For example, the
    dimension city indicates the city from which an event
    originates. Dimension values in report responses are strings;
    for example, city could be "Paris" or "New York". Requests are
    allowed up to 8 dimensions.

    Attributes:
        name (str):
            The name of the dimension. See the `API
            Dimensions <https://developers.google.com/analytics/devguides/reporting/data/v1/api-schema#dimensions>`__
            for the list of dimension names.

            If ``dimensionExpression`` is specified, ``name`` can be any
            string that you would like. For example if a
            ``dimensionExpression`` concatenates ``country`` and
            ``city``, you could call that dimension ``countryAndCity``.

            Dimensions are referenced by ``name`` in
            ``dimensionFilter``, ``orderBys``, ``dimensionExpression``,
            and ``pivots``.
        dimension_expression (google.analytics.data_v1alpha.types.DimensionExpression):
            One dimension can be the result of an
            expression of multiple dimensions. For example,
            dimension "country, city": concatenate(country,
            ", ", city).
    """

    name = proto.Field(proto.STRING, number=1,)
    dimension_expression = proto.Field(
        proto.MESSAGE, number=2, message="DimensionExpression",
    )


class DimensionExpression(proto.Message):
    r"""Used to express a dimension which is the result of a formula of
    multiple dimensions. Example usages:

    1) lower_case(dimension)
    2) concatenate(dimension1, symbol, dimension2).

    Attributes:
        lower_case (google.analytics.data_v1alpha.types.DimensionExpression.CaseExpression):
            Used to convert a dimension value to lower
            case.
        upper_case (google.analytics.data_v1alpha.types.DimensionExpression.CaseExpression):
            Used to convert a dimension value to upper
            case.
        concatenate (google.analytics.data_v1alpha.types.DimensionExpression.ConcatenateExpression):
            Used to combine dimension values to a single
            dimension. For example, dimension "country,
            city": concatenate(country, ", ", city).
    """

    class CaseExpression(proto.Message):
        r"""Used to convert a dimension value to a single case.
        Attributes:
            dimension_name (str):
                Name of a dimension. The name must refer back
                to a name in dimensions field of the request.
        """

        dimension_name = proto.Field(proto.STRING, number=1,)

    class ConcatenateExpression(proto.Message):
        r"""Used to combine dimension values to a single dimension.
        Attributes:
            dimension_names (Sequence[str]):
                Names of dimensions. The names must refer
                back to names in the dimensions field of the
                request.
            delimiter (str):
                The delimiter placed between dimension names.

                Delimiters are often single characters such as "|" or ","
                but can be longer strings. If a dimension value contains the
                delimiter, both will be present in response with no
                distinction. For example if dimension 1 value = "US,FR",
                dimension 2 value = "JP", and delimiter = ",", then the
                response will contain "US,FR,JP".
        """

        dimension_names = proto.RepeatedField(proto.STRING, number=1,)
        delimiter = proto.Field(proto.STRING, number=2,)

    lower_case = proto.Field(
        proto.MESSAGE, number=4, oneof="one_expression", message=CaseExpression,
    )
    upper_case = proto.Field(
        proto.MESSAGE, number=5, oneof="one_expression", message=CaseExpression,
    )
    concatenate = proto.Field(
        proto.MESSAGE, number=6, oneof="one_expression", message=ConcatenateExpression,
    )


class Metric(proto.Message):
    r"""The quantitative measurements of a report. For example, the metric
    ``eventCount`` is the total number of events. Requests are allowed
    up to 10 metrics.

    Attributes:
        name (str):
            The name of the metric. See the `API
            Metrics <https://developers.google.com/analytics/devguides/reporting/data/v1/api-schema#metrics>`__
            for the list of metric names.

            If ``expression`` is specified, ``name`` can be any string
            that you would like. For example if ``expression`` is
            ``screenPageViews/sessions``, you could call that metric's
            name = ``viewsPerSession``.

            Metrics are referenced by ``name`` in ``metricFilter``,
            ``orderBys``, and metric ``expression``.
        expression (str):
            A mathematical expression for derived metrics. For example,
            the metric Event count per user is
            ``eventCount/totalUsers``.
        invisible (bool):
            Indicates if a metric is invisible in the report response.
            If a metric is invisible, the metric will not produce a
            column in the response, but can be used in ``metricFilter``,
            ``orderBys``, or a metric ``expression``.
    """

    name = proto.Field(proto.STRING, number=1,)
    expression = proto.Field(proto.STRING, number=2,)
    invisible = proto.Field(proto.BOOL, number=3,)


class FilterExpression(proto.Message):
    r"""To express dimension or metric filters.
    The fields in the same FilterExpression need to be either all
    dimensions or all metrics.

    Attributes:
        and_group (google.analytics.data_v1alpha.types.FilterExpressionList):
            The FilterExpressions in and_group have an AND relationship.
        or_group (google.analytics.data_v1alpha.types.FilterExpressionList):
            The FilterExpressions in or_group have an OR relationship.
        not_expression (google.analytics.data_v1alpha.types.FilterExpression):
            The FilterExpression is NOT of not_expression.
        filter (google.analytics.data_v1alpha.types.Filter):
            A primitive filter.
            All fields in filter in same FilterExpression
            needs to be either all dimensions or metrics.
    """

    and_group = proto.Field(
        proto.MESSAGE, number=1, oneof="expr", message="FilterExpressionList",
    )
    or_group = proto.Field(
        proto.MESSAGE, number=2, oneof="expr", message="FilterExpressionList",
    )
    not_expression = proto.Field(
        proto.MESSAGE, number=3, oneof="expr", message="FilterExpression",
    )
    filter = proto.Field(proto.MESSAGE, number=4, oneof="expr", message="Filter",)


class FilterExpressionList(proto.Message):
    r"""A list of filter expressions.
    Attributes:
        expressions (Sequence[google.analytics.data_v1alpha.types.FilterExpression]):
            A list of filter expressions.
    """

    expressions = proto.RepeatedField(
        proto.MESSAGE, number=1, message="FilterExpression",
    )


class Filter(proto.Message):
    r"""An expression to filter dimension or metric values.
    Attributes:
        field_name (str):
            The dimension name or metric name. Must be a
            name defined in dimensions or metrics.
        null_filter (bool):
            A filter for null values. If True, a null
            dimension value is matched by this filter. Null
            filter is commonly used inside a NOT filter
            expression. For example, a NOT expression of a
            null filter removes rows when a dimension is
            null.
        string_filter (google.analytics.data_v1alpha.types.Filter.StringFilter):
            Strings related filter.
        in_list_filter (google.analytics.data_v1alpha.types.Filter.InListFilter):
            A filter for in list values.
        numeric_filter (google.analytics.data_v1alpha.types.Filter.NumericFilter):
            A filter for numeric or date values.
        between_filter (google.analytics.data_v1alpha.types.Filter.BetweenFilter):
            A filter for two values.
    """

    class StringFilter(proto.Message):
        r"""The filter for string
        Attributes:
            match_type (google.analytics.data_v1alpha.types.Filter.StringFilter.MatchType):
                The match type for this filter.
            value (str):
                The string value used for the matching.
            case_sensitive (bool):
                If true, the string value is case sensitive.
        """

        class MatchType(proto.Enum):
            r"""The match type of a string filter"""
            MATCH_TYPE_UNSPECIFIED = 0
            EXACT = 1
            BEGINS_WITH = 2
            ENDS_WITH = 3
            CONTAINS = 4
            FULL_REGEXP = 5
            PARTIAL_REGEXP = 6

        match_type = proto.Field(
            proto.ENUM, number=1, enum="Filter.StringFilter.MatchType",
        )
        value = proto.Field(proto.STRING, number=2,)
        case_sensitive = proto.Field(proto.BOOL, number=3,)

    class InListFilter(proto.Message):
        r"""The result needs to be in a list of string values.
        Attributes:
            values (Sequence[str]):
                The list of string values.
                Must be non-empty.
            case_sensitive (bool):
                If true, the string value is case sensitive.
        """

        values = proto.RepeatedField(proto.STRING, number=1,)
        case_sensitive = proto.Field(proto.BOOL, number=2,)

    class NumericFilter(proto.Message):
        r"""Filters for numeric or date values.
        Attributes:
            operation (google.analytics.data_v1alpha.types.Filter.NumericFilter.Operation):
                The operation type for this filter.
            value (google.analytics.data_v1alpha.types.NumericValue):
                A numeric value or a date value.
        """

        class Operation(proto.Enum):
            r"""The operation applied to a numeric filter"""
            OPERATION_UNSPECIFIED = 0
            EQUAL = 1
            LESS_THAN = 2
            LESS_THAN_OR_EQUAL = 3
            GREATER_THAN = 4
            GREATER_THAN_OR_EQUAL = 5

        operation = proto.Field(
            proto.ENUM, number=1, enum="Filter.NumericFilter.Operation",
        )
        value = proto.Field(proto.MESSAGE, number=2, message="NumericValue",)

    class BetweenFilter(proto.Message):
        r"""To express that the result needs to be between two numbers
        (inclusive).

        Attributes:
            from_value (google.analytics.data_v1alpha.types.NumericValue):
                Begins with this number.
            to_value (google.analytics.data_v1alpha.types.NumericValue):
                Ends with this number.
        """

        from_value = proto.Field(proto.MESSAGE, number=1, message="NumericValue",)
        to_value = proto.Field(proto.MESSAGE, number=2, message="NumericValue",)

    field_name = proto.Field(proto.STRING, number=1,)
    null_filter = proto.Field(proto.BOOL, number=2, oneof="one_filter",)
    string_filter = proto.Field(
        proto.MESSAGE, number=3, oneof="one_filter", message=StringFilter,
    )
    in_list_filter = proto.Field(
        proto.MESSAGE, number=4, oneof="one_filter", message=InListFilter,
    )
    numeric_filter = proto.Field(
        proto.MESSAGE, number=5, oneof="one_filter", message=NumericFilter,
    )
    between_filter = proto.Field(
        proto.MESSAGE, number=6, oneof="one_filter", message=BetweenFilter,
    )


class OrderBy(proto.Message):
    r"""The sort options.
    Attributes:
        metric (google.analytics.data_v1alpha.types.OrderBy.MetricOrderBy):
            Sorts results by a metric's values.
        dimension (google.analytics.data_v1alpha.types.OrderBy.DimensionOrderBy):
            Sorts results by a dimension's values.
        pivot (google.analytics.data_v1alpha.types.OrderBy.PivotOrderBy):
            Sorts results by a metric's values within a
            pivot column group.
        desc (bool):
            If true, sorts by descending order.
    """

    class MetricOrderBy(proto.Message):
        r"""Sorts by metric values.
        Attributes:
            metric_name (str):
                A metric name in the request to order by.
        """

        metric_name = proto.Field(proto.STRING, number=1,)

    class DimensionOrderBy(proto.Message):
        r"""Sorts by dimension values.
        Attributes:
            dimension_name (str):
                A dimension name in the request to order by.
            order_type (google.analytics.data_v1alpha.types.OrderBy.DimensionOrderBy.OrderType):
                Controls the rule for dimension value
                ordering.
        """

        class OrderType(proto.Enum):
            r"""Rule to order the string dimension values by."""
            ORDER_TYPE_UNSPECIFIED = 0
            ALPHANUMERIC = 1
            CASE_INSENSITIVE_ALPHANUMERIC = 2
            NUMERIC = 3

        dimension_name = proto.Field(proto.STRING, number=1,)
        order_type = proto.Field(
            proto.ENUM, number=2, enum="OrderBy.DimensionOrderBy.OrderType",
        )

    class PivotOrderBy(proto.Message):
        r"""Sorts by a pivot column group.
        Attributes:
            metric_name (str):
                In the response to order by, order rows by
                this column. Must be a metric name from the
                request.
            pivot_selections (Sequence[google.analytics.data_v1alpha.types.OrderBy.PivotOrderBy.PivotSelection]):
                Used to select a dimension name and value
                pivot. If multiple pivot selections are given,
                the sort occurs on rows where all pivot
                selection dimension name and value pairs match
                the row's dimension name and value pair.
        """

        class PivotSelection(proto.Message):
            r"""A pair of dimension names and values. Rows with this dimension pivot
            pair are ordered by the metric's value.

            For example if pivots = {{"browser", "Chrome"}} and metric_name =
            "Sessions", then the rows will be sorted based on Sessions in
            Chrome.

            ::

                ---------|----------|----------------|----------|----------------
                         |  Chrome  |    Chrome      |  Safari  |     Safari
                ---------|----------|----------------|----------|----------------
                 Country | Sessions | Pages/Sessions | Sessions | Pages/Sessions
                ---------|----------|----------------|----------|----------------
                    US   |    2     |       2        |     3    |        1
                ---------|----------|----------------|----------|----------------
                  Canada |    3     |       1        |     4    |        1
                ---------|----------|----------------|----------|----------------

            Attributes:
                dimension_name (str):
                    Must be a dimension name from the request.
                dimension_value (str):
                    Order by only when the named dimension is
                    this value.
            """

            dimension_name = proto.Field(proto.STRING, number=1,)
            dimension_value = proto.Field(proto.STRING, number=2,)

        metric_name = proto.Field(proto.STRING, number=1,)
        pivot_selections = proto.RepeatedField(
            proto.MESSAGE, number=2, message="OrderBy.PivotOrderBy.PivotSelection",
        )

    metric = proto.Field(
        proto.MESSAGE, number=1, oneof="one_order_by", message=MetricOrderBy,
    )
    dimension = proto.Field(
        proto.MESSAGE, number=2, oneof="one_order_by", message=DimensionOrderBy,
    )
    pivot = proto.Field(
        proto.MESSAGE, number=3, oneof="one_order_by", message=PivotOrderBy,
    )
    desc = proto.Field(proto.BOOL, number=4,)


class Pivot(proto.Message):
    r"""Describes the visible dimension columns and rows in the
    report response.

    Attributes:
        field_names (Sequence[str]):
            Dimension names for visible columns in the
            report response. Including "dateRange" produces
            a date range column; for each row in the
            response, dimension values in the date range
            column will indicate the corresponding date
            range from the request.
        order_bys (Sequence[google.analytics.data_v1alpha.types.OrderBy]):
            Specifies how dimensions are ordered in the pivot. In the
            first Pivot, the OrderBys determine Row and
            PivotDimensionHeader ordering; in subsequent Pivots, the
            OrderBys determine only PivotDimensionHeader ordering.
            Dimensions specified in these OrderBys must be a subset of
            Pivot.field_names.
        offset (int):
            The row count of the start row. The first row
            is counted as row 0.
        limit (int):
            The number of rows to return in this pivot.
            If unspecified, 10 rows are returned. If -1, all
            rows are returned.
        metric_aggregations (Sequence[google.analytics.data_v1alpha.types.MetricAggregation]):
            Aggregate the metrics by dimensions in this pivot using the
            specified metric_aggregations.
    """

    field_names = proto.RepeatedField(proto.STRING, number=1,)
    order_bys = proto.RepeatedField(proto.MESSAGE, number=2, message="OrderBy",)
    offset = proto.Field(proto.INT64, number=3,)
    limit = proto.Field(proto.INT64, number=4,)
    metric_aggregations = proto.RepeatedField(
        proto.ENUM, number=5, enum="MetricAggregation",
    )


class CohortSpec(proto.Message):
    r"""Specification of cohorts for a cohort report. Cohort reports can be
    used for example to create a time series of user retention for the
    cohort. For example, you could select the cohort of users that were
    acquired in the first week of September and follow that cohort for
    the next six weeks. Selecting the users acquired in the first week
    of September cohort is specified in the ``cohort`` object. Following
    that cohort for the next six weeks is specified in the
    ``cohortsRange`` object.

    The report response could show a weekly time series where say your
    app has retained 60% of this cohort after three weeks and 25% of
    this cohort after six weeks. These two percentages can be calculated
    by the metric ``cohortActiveUsers/cohortTotalUsers`` and will be
    separate rows in the report.

    Attributes:
        cohorts (Sequence[google.analytics.data_v1alpha.types.Cohort]):
            Defines the selection criteria to group users
            into cohorts.
            Most cohort reports define only a single cohort.
            If multiple cohorts are specified, each cohort
            can be recognized in the report by their name.
        cohorts_range (google.analytics.data_v1alpha.types.CohortsRange):
            Cohort reports follow cohorts over an
            extended reporting date range. This range
            specifies an offset duration to follow the
            cohorts over.
        cohort_report_settings (google.analytics.data_v1alpha.types.CohortReportSettings):
            Optional settings for a cohort report.
    """

    cohorts = proto.RepeatedField(proto.MESSAGE, number=1, message="Cohort",)
    cohorts_range = proto.Field(proto.MESSAGE, number=2, message="CohortsRange",)
    cohort_report_settings = proto.Field(
        proto.MESSAGE, number=3, message="CohortReportSettings",
    )


class Cohort(proto.Message):
    r"""Defines a cohort selection criteria. A cohort is a group of users
    who share a common characteristic. For example, users with the same
    ``firstTouchDate`` belong to the same cohort.

    Attributes:
        name (str):
            Assigns a name to this cohort. The dimension ``cohort`` is
            valued to this name in a report response. If set, cannot
            begin with ``cohort_`` or ``RESERVED_``. If not set, cohorts
            are named by their zero based index ``cohort_0``,
            ``cohort_1``, etc.
        dimension (str):
            Dimension used by the cohort. Required and only supports
            ``firstTouchDate``.
        date_range (google.analytics.data_v1alpha.types.DateRange):
            The cohort selects users whose first touch date is between
            start date and end date defined in the ``dateRange``. This
            ``dateRange`` does not specify the full date range of event
            data that is present in a cohort report. In a cohort report,
            this ``dateRange`` is extended by the granularity and offset
            present in the ``cohortsRange``; event data for the extended
            reporting date range is present in a cohort report.

            In a cohort request, this ``dateRange`` is required and the
            ``dateRanges`` in the ``RunReportRequest`` or
            ``RunPivotReportRequest`` must be unspecified.

            This ``dateRange`` should generally be aligned with the
            cohort's granularity. If ``CohortsRange`` uses daily
            granularity, this ``dateRange`` can be a single day. If
            ``CohortsRange`` uses weekly granularity, this ``dateRange``
            can be aligned to a week boundary, starting at Sunday and
            ending Saturday. If ``CohortsRange`` uses monthly
            granularity, this ``dateRange`` can be aligned to a month,
            starting at the first and ending on the last day of the
            month.
    """

    name = proto.Field(proto.STRING, number=1,)
    dimension = proto.Field(proto.STRING, number=2,)
    date_range = proto.Field(proto.MESSAGE, number=3, message="DateRange",)


class CohortsRange(proto.Message):
    r"""Configures the extended reporting date range for a cohort
    report. Specifies an offset duration to follow the cohorts over.

    Attributes:
        granularity (google.analytics.data_v1alpha.types.CohortsRange.Granularity):
            The granularity used to interpret the ``startOffset`` and
            ``endOffset`` for the extended reporting date range for a
            cohort report.
        start_offset (int):
            ``startOffset`` specifies the start date of the extended
            reporting date range for a cohort report. ``startOffset`` is
            commonly set to 0 so that reports contain data from the
            acquisition of the cohort forward.

            If ``granularity`` is ``DAILY``, the ``startDate`` of the
            extended reporting date range is ``startDate`` of the cohort
            plus ``startOffset`` days.

            If ``granularity`` is ``WEEKLY``, the ``startDate`` of the
            extended reporting date range is ``startDate`` of the cohort
            plus ``startOffset * 7`` days.

            If ``granularity`` is ``MONTHLY``, the ``startDate`` of the
            extended reporting date range is ``startDate`` of the cohort
            plus ``startOffset * 30`` days.
        end_offset (int):
            ``endOffset`` specifies the end date of the extended
            reporting date range for a cohort report. ``endOffset`` can
            be any positive integer but is commonly set to 5 to 10 so
            that reports contain data on the cohort for the next several
            granularity time periods.

            If ``granularity`` is ``DAILY``, the ``endDate`` of the
            extended reporting date range is ``endDate`` of the cohort
            plus ``endOffset`` days.

            If ``granularity`` is ``WEEKLY``, the ``endDate`` of the
            extended reporting date range is ``endDate`` of the cohort
            plus ``endOffset * 7`` days.

            If ``granularity`` is ``MONTHLY``, the ``endDate`` of the
            extended reporting date range is ``endDate`` of the cohort
            plus ``endOffset * 30`` days.
    """

    class Granularity(proto.Enum):
        r"""The granularity used to interpret the ``startOffset`` and
        ``endOffset`` for the extended reporting date range for a cohort
        report.
        """
        GRANULARITY_UNSPECIFIED = 0
        DAILY = 1
        WEEKLY = 2
        MONTHLY = 3

    granularity = proto.Field(proto.ENUM, number=1, enum=Granularity,)
    start_offset = proto.Field(proto.INT32, number=2,)
    end_offset = proto.Field(proto.INT32, number=3,)


class CohortReportSettings(proto.Message):
    r"""Optional settings of a cohort report.
    Attributes:
        accumulate (bool):
            If true, accumulates the result from first touch day to the
            end day. Not supported in ``RunReportRequest``.
    """

    accumulate = proto.Field(proto.BOOL, number=1,)


class ResponseMetaData(proto.Message):
    r"""Response's metadata carrying additional information about the
    report content.

    Attributes:
        data_loss_from_other_row (bool):
            If true, indicates some buckets of dimension
            combinations are rolled into "(other)" row. This
            can happen for high cardinality reports.
    """

    data_loss_from_other_row = proto.Field(proto.BOOL, number=3,)


class DimensionHeader(proto.Message):
    r"""Describes a dimension column in the report. Dimensions
    requested in a report produce column entries within rows and
    DimensionHeaders. However, dimensions used exclusively within
    filters or expressions do not produce columns in a report;
    correspondingly, those dimensions do not produce headers.

    Attributes:
        name (str):
            The dimension's name.
    """

    name = proto.Field(proto.STRING, number=1,)


class MetricHeader(proto.Message):
    r"""Describes a metric column in the report. Visible metrics
    requested in a report produce column entries within rows and
    MetricHeaders. However, metrics used exclusively within filters
    or expressions do not produce columns in a report;
    correspondingly, those metrics do not produce headers.

    Attributes:
        name (str):
            The metric's name.
        type_ (google.analytics.data_v1alpha.types.MetricType):
            The metric's data type.
    """

    name = proto.Field(proto.STRING, number=1,)
    type_ = proto.Field(proto.ENUM, number=2, enum="MetricType",)


class PivotHeader(proto.Message):
    r"""Dimensions' values in a single pivot.
    Attributes:
        pivot_dimension_headers (Sequence[google.analytics.data_v1alpha.types.PivotDimensionHeader]):
            The size is the same as the cardinality of
            the corresponding dimension combinations.
        row_count (int):
            The cardinality of the pivot as if offset = 0
            and limit = -1. The total number of rows for
            this pivot's fields regardless of how the
            parameters offset and limit are specified in the
            request.
    """

    pivot_dimension_headers = proto.RepeatedField(
        proto.MESSAGE, number=1, message="PivotDimensionHeader",
    )
    row_count = proto.Field(proto.INT32, number=2,)


class PivotDimensionHeader(proto.Message):
    r"""Summarizes dimension values from a row for this pivot.
    Attributes:
        dimension_values (Sequence[google.analytics.data_v1alpha.types.DimensionValue]):
            Values of multiple dimensions in a pivot.
    """

    dimension_values = proto.RepeatedField(
        proto.MESSAGE, number=1, message="DimensionValue",
    )


class Row(proto.Message):
    r"""Report data for each row. For example if RunReportRequest contains:

    .. code:: none

       "dimensions": [
         {
           "name": "eventName"
         },
         {
           "name": "countryId"
         }
       ],
       "metrics": [
         {
           "name": "eventCount"
         }
       ]

    One row with 'in_app_purchase' as the eventName, 'JP' as the
    countryId, and 15 as the eventCount, would be:

    .. code:: none

       "dimensionValues": [
         {
           "value": "in_app_purchase"
         },
         {
           "value": "JP"
         }
       ],
       "metricValues": [
         {
           "value": "15"
         }
       ]

    Attributes:
        dimension_values (Sequence[google.analytics.data_v1alpha.types.DimensionValue]):
            List of requested dimension values. In a PivotReport,
            dimension_values are only listed for dimensions included in
            a pivot.
        metric_values (Sequence[google.analytics.data_v1alpha.types.MetricValue]):
            List of requested visible metric values.
    """

    dimension_values = proto.RepeatedField(
        proto.MESSAGE, number=1, message="DimensionValue",
    )
    metric_values = proto.RepeatedField(proto.MESSAGE, number=2, message="MetricValue",)


class DimensionValue(proto.Message):
    r"""The value of a dimension.
    Attributes:
        value (str):
            Value as a string if the dimension type is a
            string.
    """

    value = proto.Field(proto.STRING, number=1, oneof="one_value",)


class MetricValue(proto.Message):
    r"""The value of a metric.
    Attributes:
        value (str):
            Measurement value. See MetricHeader for type.
    """

    value = proto.Field(proto.STRING, number=4, oneof="one_value",)


class NumericValue(proto.Message):
    r"""To represent a number.
    Attributes:
        int64_value (int):
            Integer value
        double_value (float):
            Double value
    """

    int64_value = proto.Field(proto.INT64, number=1, oneof="one_value",)
    double_value = proto.Field(proto.DOUBLE, number=2, oneof="one_value",)


class PropertyQuota(proto.Message):
    r"""Current state of all quotas for this Analytics Property. If
    any quota for a property is exhausted, all requests to that
    property will return Resource Exhausted errors.

    Attributes:
        tokens_per_day (google.analytics.data_v1alpha.types.QuotaStatus):
            Standard Analytics Properties can use up to
            25,000 tokens per day; Analytics 360 Properties
            can use 250,000 tokens per day. Most requests
            consume fewer than 10 tokens.
        tokens_per_hour (google.analytics.data_v1alpha.types.QuotaStatus):
            Standard Analytics Properties can use up to
            5,000 tokens per day; Analytics 360 Properties
            can use 50,000 tokens per day. An API request
            consumes a single number of tokens, and that
            number is deducted from both the hourly and
            daily quotas.
        concurrent_requests (google.analytics.data_v1alpha.types.QuotaStatus):
            Standard Analytics Properties can send up to
            10 concurrent requests; Analytics 360 Properties
            can use up to 50 concurrent requests.
        server_errors_per_project_per_hour (google.analytics.data_v1alpha.types.QuotaStatus):
            Standard Analytics Properties and cloud
            project pairs can have up to 10 server errors
            per hour; Analytics 360 Properties and cloud
            project pairs can have up to 50 server errors
            per hour.
    """

    tokens_per_day = proto.Field(proto.MESSAGE, number=1, message="QuotaStatus",)
    tokens_per_hour = proto.Field(proto.MESSAGE, number=2, message="QuotaStatus",)
    concurrent_requests = proto.Field(proto.MESSAGE, number=3, message="QuotaStatus",)
    server_errors_per_project_per_hour = proto.Field(
        proto.MESSAGE, number=4, message="QuotaStatus",
    )


class QuotaStatus(proto.Message):
    r"""Current state for a particular quota group.
    Attributes:
        consumed (int):
            Quota consumed by this request.
        remaining (int):
            Quota remaining after this request.
    """

    consumed = proto.Field(proto.INT32, number=1,)
    remaining = proto.Field(proto.INT32, number=2,)


class DimensionMetadata(proto.Message):
    r"""Explains a dimension.
    Attributes:
        api_name (str):
            This dimension's name. Useable in
            `Dimension <#Dimension>`__'s ``name``. For example,
            ``eventName``.
        ui_name (str):
            This dimension's name within the Google Analytics user
            interface. For example, ``Event name``.
        description (str):
            Description of how this dimension is used and
            calculated.
        deprecated_api_names (Sequence[str]):
            Still usable but deprecated names for this dimension. If
            populated, this dimension is available by either ``apiName``
            or one of ``deprecatedApiNames`` for a period of time. After
            the deprecation period, the dimension will be available only
            by ``apiName``.
        custom_definition (bool):
            True if the dimension is a custom dimension
            for this property.
    """

    api_name = proto.Field(proto.STRING, number=1,)
    ui_name = proto.Field(proto.STRING, number=2,)
    description = proto.Field(proto.STRING, number=3,)
    deprecated_api_names = proto.RepeatedField(proto.STRING, number=4,)
    custom_definition = proto.Field(proto.BOOL, number=5,)


class MetricMetadata(proto.Message):
    r"""Explains a metric.
    Attributes:
        api_name (str):
            A metric name. Useable in `Metric <#Metric>`__'s ``name``.
            For example, ``eventCount``.
        ui_name (str):
            This metric's name within the Google Analytics user
            interface. For example, ``Event count``.
        description (str):
            Description of how this metric is used and
            calculated.
        deprecated_api_names (Sequence[str]):
            Still usable but deprecated names for this metric. If
            populated, this metric is available by either ``apiName`` or
            one of ``deprecatedApiNames`` for a period of time. After
            the deprecation period, the metric will be available only by
            ``apiName``.
        type_ (google.analytics.data_v1alpha.types.MetricType):
            The type of this metric.
        expression (str):
            The mathematical expression for this derived metric. Can be
            used in `Metric <#Metric>`__'s ``expression`` field for
            equivalent reports. Most metrics are not expressions, and
            for non-expressions, this field is empty.
        custom_definition (bool):
            True if the metric is a custom metric for
            this property.
    """

    api_name = proto.Field(proto.STRING, number=1,)
    ui_name = proto.Field(proto.STRING, number=2,)
    description = proto.Field(proto.STRING, number=3,)
    deprecated_api_names = proto.RepeatedField(proto.STRING, number=4,)
    type_ = proto.Field(proto.ENUM, number=5, enum="MetricType",)
    expression = proto.Field(proto.STRING, number=6,)
    custom_definition = proto.Field(proto.BOOL, number=7,)


__all__ = tuple(sorted(__protobuf__.manifest))
